==> nmrium-0.50.1.tgz: package/lib/component/modal/setting/WorkspaceItem.js <==
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useState } from 'react';
import { FaTimes } from 'react-icons/fa';
import Button from '../../elements/Button';
const styles = {
    container: {
        display: 'flex',
        alignItems: 'center',
        padding: '0 5px',
    },
    workspaceName: {
        flex: '1',
        textAlign: 'left',
        fontSize: '11px',
        padding: '5px',
    },
    workspaceVersion: {
        fontSize: '9px',
        padding: '5px',
    },
    readOnly: {
        fontSize: '9px',
        padding: '0 5px',
        border: '1px solid #00d5ff',
        borderRadius: '10px',
    },
    newContainer: {
        backgroundColor: '#f6f6f6',
        display: 'flex',
        padding: '0.3em',
    },
    input: {
        padding: '0.5em 0.8em',
        fontSize: '12px',
        color: 'black',
        outline: 'none',
        backgroundColor: 'transparent',
        flex: 1,
    },
};
function WorkspaceItem({ item, onSave, onDelete }) {
    const [name, setName] = useState('');
    // Add new workspace
    function addHandler(e) {
        e.stopPropagation();
        setName('');
        onSave?.(name);
    }
    // bubble onDelete
    function deleteHandler(e) {
        e.stopPropagation();
        onDelete?.(item.key);
    }
    function onTextChange(e) {
        setName(e.target.value);
    }
    return (_jsx("div", { children: item.key === 'new' ? (_jsxs("div", { style: styles.newContainer, children: [_jsx("input", { style: styles.input, value: name, placeholder: "Custom workspace", onClick: (e) => e.stopPropagation(), onChange: onTextChange }), _jsx(Button.Done, { onClick: addHandler, disabled: !name, style: { fontSize: '11px' }, children: "Save" })] })) : (_jsxs("div", { style: styles.container, children: [_jsx(WorkSpaceIndicator, { source: item.source }), _jsx("span", { style: styles.workspaceName, children: item.label }), item.source !== 'user' && (_jsx("span", { style: styles.readOnly, children: "Read Only" })), item.source === 'user' && onDelete && (_jsx(Button.Danger, { onClick: deleteHandler, size: "xSmall", fill: "clear", children: _jsx(FaTimes, {}) })), item.version && !item.isReadOnly && (_jsxs("span", { style: styles.workspaceVersion, children: ["V", item.version] }))] })) }));
}
const style = {
    width: '20px',
    height: '20px',
    borderRadius: '50%',
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
};
const WorkSpaceIndicator = (props) => {
    let letter = '';
    let backgroundColor = 'red';
    switch (props.source) {
        case 'predefined':
            letter = 'P';
            backgroundColor = '#2dd36f';
            break;
        case 'custom':
            letter = 'C';
            backgroundColor = '#ffbe05';
            break;
        case 'component':
            letter = 'NC';
            backgroundColor = '#cccccc';
            break;
        case 'nmriumFile':
            letter = 'NF';
            backgroundColor = '#cccccc';
            break;
        case 'user':
            letter = 'U';
            backgroundColor = '#ff6f00';
            break;
        default:
            break;
    }
    return (_jsx("div", { style: { ...style, backgroundColor }, children: _jsx("span", { style: { fontWeight: 'bolder' }, children: letter }) }));
};
export default WorkspaceItem;

==> nmrium-0.55.0.tgz: package/lib/component/modal/setting/WorkspaceItem.js <==
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useState } from 'react';
import { FaTimes } from 'react-icons/fa';
import Button from '../../elements/Button';
const styles = {
    container: {
        display: 'flex',
        alignItems: 'center',
        padding: '0 5px',
    },
    workspaceName: {
        flex: '1',
        textAlign: 'left',
        fontSize: '11px',
        padding: '5px',
    },
    workspaceVersion: {
        fontSize: '9px',
        padding: '5px',
    },
    readOnly: {
        fontSize: '9px',
        padding: '0 5px',
        border: '1px solid #00d5ff',
        borderRadius: '10px',
    },
    newContainer: {
        backgroundColor: '#f6f6f6',
        display: 'flex',
        padding: '0.3em',
    },
    input: {
        padding: '0.5em 0.8em',
        fontSize: '12px',
        color: 'black',
        outline: 'none',
        backgroundColor: 'transparent',
        flex: 1,
    },
};
function WorkspaceItem({ item, onSave, onDelete }) {
    const [name, setName] = useState('');
    // Add new workspace
    function addHandler(e) {
        e.stopPropagation();
        setName('');
        onSave?.(name);
    }
    // bubble onDelete
    function deleteHandler(e) {
        e.stopPropagation();
        onDelete?.(item.key);
    }
    function onTextChange(e) {
        setName(e.target.value);
    }
    return (_jsx("div", { children: item.key === 'new' ? (_jsxs("div", { style: styles.newContainer, children: [_jsx("input", { style: styles.input, value: name, placeholder: "Custom workspace", onClick: (e) => e.stopPropagation(), onChange: onTextChange }), _jsx(Button.Done, { onClick: addHandler, disabled: !name, style: { fontSize: '11px' }, children: "Save" })] })) : (_jsxs("div", { style: styles.container, children: [_jsx(WorkSpaceIndicator, { source: item.source }), _jsx("span", { style: styles.workspaceName, children: item.label }), item.source !== 'user' && (_jsx("span", { style: styles.readOnly, children: "Read Only" })), item.source === 'user' && onDelete && (_jsx(Button.Danger, { onClick: deleteHandler, size: "xSmall", fill: "clear", children: _jsx(FaTimes, {}) }))] })) }));
}
const style = {
    width: '20px',
    height: '20px',
    borderRadius: '50%',
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
};
const WorkSpaceIndicator = (props) => {
    let letter = '';
    let backgroundColor = 'red';
    switch (props.source) {
        case 'predefined':
            letter = 'P';
            backgroundColor = '#2dd36f';
            break;
        case 'custom':
            letter = 'C';
            backgroundColor = '#ffbe05';
            break;
        case 'component':
            letter = 'NC';
            backgroundColor = '#cccccc';
            break;
        case 'nmriumFile':
            letter = 'NF';
            backgroundColor = '#cccccc';
            break;
        case 'user':
            letter = 'U';
            backgroundColor = '#ff6f00';
            break;
        default:
            break;
    }
    return (_jsx("div", { style: { ...style, backgroundColor }, children: _jsx("span", { style: { fontWeight: 'bolder' }, children: letter }) }));
};
export default WorkspaceItem;
